Structs
- Outcome
- The result of
command_line().
Enums
- Error
- The error returned when a command line cannot be parsed into a command.
Functions
- command_
line - Split
inputinto leading environment assignments and the command with its arguments.