Module parse

Module parse 

Structs

Outcome
The result of command_line().

Enums

Error
The error returned when a command line cannot be parsed into a command.

Functions

command_line
Split input into leading environment assignments and the command with its arguments.